@@ -1,11 +1,12 @@
 from dataclasses import dataclass
 from annotell.input_api.model.abstract.abstract_models import Response
+from typing import Union
 
 
 @dataclass
 class Annotation(Response):
     annotation_id: int
-    export_content: dict
+    export_content: Union[list, dict]
 
     @staticmethod
     def from_json(js: dict):
