@@ -21,6 +21,7 @@ class Input(Response):
     batch: str
     input_type: str
     status: InputStatus
+    view_link: Optional[str]
     error_message: Optional[str]
 
     @staticmethod
@@ -31,5 +32,6 @@ class Input(Response):
             js["batchId"],
             js["inputType"],
             js["status"],
+            js.get("viewLink"),
             js.get("errorMessage")
         )
