@@ -1,7 +1,6 @@
 from typing import List
 
-import annotell.input_api.model.project as ProjectModel
-import annotell.input_api.model.input as InputModel
+import annotell.input_api.model.projects as ProjectModel
 from annotell.input_api.resources.abstract import InputAPIResource
 
 
@@ -16,24 +15,24 @@ class ProjectResource(InputAPIResource):
 
         :return List: List containing all projects connected to the user
         """
-        json_resp = self.client.get("v1/projects")
+        json_resp = self._client.get("v1/projects")
         return [ProjectModel.Project.from_json(js) for js in json_resp]
 
-    def get_project_batches(self, project: str) -> List[ProjectModel.Project]:
+    def get_project_batches(self, project: str) -> List[ProjectModel.ProjectBatch]:
         """
         Returns all `batches` for the `project`.
 
         :return List: List containing all batches
         """
-        json_resp = self.client.get(f"v1/projects/{project}/batches")
-        return [InputModel.ProjectBatch.from_json(js) for js in json_resp]
+        json_resp = self._client.get(f"v1/projects/{project}/batches")
+        return [ProjectModel.ProjectBatch.from_json(js) for js in json_resp]
 
-    def publish_batch(self, project: str, batch: str) -> InputModel.ProjectBatch:
+    def publish_batch(self, project: str, batch: str) -> ProjectModel.ProjectBatch:
         """
         Publish input batch, marking the input batch ready for annotation.
         After publishing, no more inputs can be added to the input batch
 
         :return ProjectBatch: Updated input batch
         """
-        json_resp = self.client.post(f"v1/projects/{project}/batches/{batch}/publish")
-        return InputModel.ProjectBatch.from_json(json_resp)
+        json_resp = self._client.post(f"v1/projects/{project}/batches/{batch}/publish")
+        return ProjectModel.ProjectBatch.from_json(json_resp)
